@@ -93,11 +93,14 @@ class talk_with_dynamo():
         response = self.table.put_item(Item=payload)
         return response
 
-    def delete(self, partition_key_attribute, sorting_key_attribute):
+    def delete(self, partition_key_attribute, sorting_key_attribute=False):
+        key = {}
+        key['UniqueID'] = partition_key_attribute
+
+        if sorting_key_attribute:
+            key['Category'] = sorting_key_attribute
+        
         response = self.table.delete_item(
-            Key={
-               'UniqueID': partition_key_attribute,
-               'Category': sorting_key_attribute
-            }
+            Key=key
         )
         return response
